%define debug_package %{nil}

Name:			analysis-pipeline
Version:		5.6
Release:		3%{?dist}
Summary:		Stream analysis of SiLK records
License:		GPLv2
Vendor:			CERT Network Situational Awareness
Source:			analysis-pipeline-%{version}.tar.gz
Group:			Applications/System
URL:			http://tools.netsa.cert.org/analysis-pipeline/
Prefix:			/usr
Requires:		silk-common >= 3.0.0
Requires(post):		/sbin/ldconfig, /sbin/chkconfig
Requires(preun):	/sbin/chkconfig
Requires(postun):	/sbin/ldconfig
Requires:		filesystem
Requires:		libfixbuf >= 1.4.0
Requires:		libschemaTools >= 1.2.0
BuildRequires:		silk-devel >= 3.0.0
BuildRequires:		libfixbuf-devel >= 1.4.0
BuildRequires:		libschemaTools-devel >= 1.2.0
BuildRequires:		zlib-devel
BuildRequires:		lzo-devel
BuildRequires:		snappy-devel
BuildRoot:		%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

#######################################################################
# RCSIDENT("$Id: analysis-pipeline.spec,v 1.19 2017/06/30 13:04:08 repoman Exp repoman $")
#######################################################################

%description
The SiLK Analysis Pipeline can be added to the SiLK packing process to
analyze flow records as they are collected by rwflowpack.

%prep
echo Building %{name}-%{version}-%{release}
%setup -q

%build
%configure --with-silk-config=/usr/bin/silk_config
make %{?_smp_mflags}

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

# Handle the daemon config file
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig
mv $RPM_BUILD_ROOT/%{_datadir}/%{name}/etc/pipeline.conf $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/pipeline.conf

# Handle the daemon config wrapper script
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/init.d
sed 's,^\(DEFAULT_SCRIPT_CONFIG_LOCATION=\),\1%{_sysconfdir}/sysconfig,' $RPM_BUILD_ROOT/%{_datadir}/%{name}/etc/init.d/pipeline > /$RPM_BUILD_ROOT/%{_sysconfdir}/init.d/pipeline
rm -f $RPM_BUILD_ROOT/%{_datadir}/%{name}/etc/init.d/pipeline

mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/%{name}

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_sbindir}/*
%{_mandir}/man8/pipeline.8*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%config(noreplace) %{_sysconfdir}/sysconfig/pipeline.conf
%config(noreplace) %{_sysconfdir}/public_suffix_list.dat
%attr(755,root,root) %{_sysconfdir}/init.d/pipeline
%attr(750,root,root) %dir %{_localstatedir}/%{name}

%post
function runlvl(){
    ( /sbin/chkconfig --del $1 || true )
    /sbin/chkconfig --add $1
    /sbin/chkconfig --levels 345 $1 on
    /sbin/chkconfig --levels 016 $1 off
}

runlvl pipeline

%preun
if [ "$1" = 0 ]; then
    /sbin/chkconfig --del pipeline
fi

%changelog
* Fri Jun 30 2017 Lawrence R. Rogers <lrr@cert.org> 5.6-3
* Release 5.6-3
	Rebuilt with silk-common-3.16.0.

* Tue Mar 28 2017 Lawrence R. Rogers <lrr@cert.org> 5.6-2
* Release 5.6-2
	Rebuilt with silk-common-3.15.0.

* Sat Jan  7 2017 Lawrence R. Rogers <lrr@cert.org> 5.6-1
* Release 5.6-1
	All fields can use a SEED file of any type
	More than one EXTRA ALERT FIELDs is now allowed.
	EXTRA ALERT FIELDs can now be derived fields
	Added EXTRA AUX ALERT FIELD to add fields to auxilliary alerts
	STATISTICs can now updated EVERY HOUR, or EVERY DAY
	STATISTICs will send one final update after processing a list of files using --name-files
	Other bug fixes

* Fri Dec  2 2016 Lawrence R. Rogers <lrr@cert.org> 5.5-2
* Release 5.5-2
	Rebuilt with silk-common-3.14.0

* Tue Oct 18 2016 Lawrence R. Rogers <lrr@cert.org> 5.5-1
* Release 5.5-1
	New PERSISTENCE primitive to detect a FOREACH tuple's presence for a specified number of HOURS or DAYS.
	A minimum number of records requirement can be added to primitives, either at the overall EVALUATION level,
	 or for each value of the FOREACH field. Alerts will not be sent until the minimum number of records is seen.
	Other bug fixes.

* Thu Jul 14 2016 Lawrence R. Rogers <lrr@cert.org> 5.4.1-1
* Release 5.4.1-1
	List configuration can now write files with the contents of the list without sending an alert.
	ICMP fields are fixed.
	Filtering by comparing two fields works with derived fields.
	Other bug fixes.

* Fri Jun  3 2016 Lawrence R. Rogers <lrr@cert.org> 5.4-1
* Release 5.4-1
	Significant memory and processing efficiency improvements.
	Streamlined Statistic processing
	Reloading of bag files used as custom thresholds upon update.

* Thu Apr  7 2016 Lawrence R. Rogers <lrr@cert.org> 5.3.2-2
* Release 5.3.2-2
	Rebuilt with silk-common-3.12.0

* Wed Feb 17 2016 Lawrence R. Rogers <lrr@cert.org> 5.3.2-1
* Release 5.3.2-1
	Pmaps are IP version agnostic. Pmaps can have both v4 and v6 address that can be used with SIP and SIP_V6.
	Small bug fixes with Ubuntu compiling and domain name processing.
	Unit test improvements

* Fri Jan 22 2016 Lawrence R. Rogers <lrr@cert.org> 5.3.1-3
* Release 5.3.1-3
	Changes for 5.3.1
		* Changed Snarf alerts when using FOREACH. Rather than a single string containing a comma separated field list and a single
		  string for the values, each value and field will be in parallel arrays, with values in appropriate format.

		* Small bug fixes.

	Change for 5.3.0
		* Expanded data inputs to include records from YAF (including all deep packet inspection fields), and any flat IPFIX records.
		* The handling of multiple data sources at once.
		* FAST FLUX primitive to detect fast flux networks from DNS records
		* Derived fields, that operate on values from the records, such as the length of a string, the second level domain from a
		  fully qualified domain name, and pulling the day of the week from a timestamp.
		* The ability to have a watchlist using any type of field, paired with the having a LIST CONFIGURATION write the contents
		  to file regardless of field type.
		* A special type of watchlist for DNS that checks each part of a domain name, rather than a generic string match.

		* First public release of Analysis Pipeline version 5.

* Tue Oct 20 2015 Lawrence R. Rogers <lrr@cert.org> 4.4.1-3
* Release 4.4.1-3
	Rebuilt with silk-common-3.11.0

* Sat Dec 20 2014 Lawrence R. Rogers <lrr@cert.org> 4.4.1-2
* Release 4.4.1-2
	Rebuilt with silk-common-3.10.0.

* Tue Oct 28 2014 Lawrence R. Rogers <lrr@cert.org> 4.4.1-1
* Release 4.4.1-1
	Pmaps files are now reloaded when updated similar to IPSet files
	Bug fix with reloading IPSet files

* Fri Sep 26 2014 Lawrence R. Rogers <lrr@cert.org> 4.4-2
* Release 4.4-2
	Rebuilt with silk-common-3.9.0.

* Tue Sep 16 2014 Lawrence R. Rogers <lrr@cert.org> 4.4-1
* Release 4.4-1
	Pmaps can be used for processing data
	List bundles added, which alert if a value is in all lists in bundle
	Filters can use bracketted list of tuples now.
	ANY IP/PORT can be used in FOREACH to build state for both

* Mon Feb 03 2014 Lawrence R. Rogers <lrr@cert.org> 4.3.2-2
* Release 4.3.2-2
	Rebuilt with silk-common-3.8.1

* Mon Dec 30 2013 Lawrence R. Rogers <lrr@cert.org> 4.3.2-1
* Release 4.3.2-1
	4.3.2: Small bug fixes
	4.3.1: CLEAR NEVER or CLEAR ALWAYS must now be specified in evals; Efficiency improvements

* Mon Apr 1 2013 Lawrence R. Rogers <lrr@cert.org> 4.2-2
* Release 4.2-2
	Rebuilt with silk-common-3.6.1

* Fri Feb 15 2013 Lawrence R. Rogers <lrr@cert.org> 4.2-1
* Release 4.2-1
	Added a new primitive: DIFFERENCE DISTRIBUTION for statistics
	Updated available fields for iterative comparison
	Statistics can now have a forever duration

* Fri Jan 4 2013 Lawrence R. Rogers <lrr@cert.org> 4.1-1
* Release 4.1-1
	Lists created by internal filters can now send alerts
	Removed the need for underscores in the config file
	Can now alert when an output is removed by an evaluation
	When pipeline runs out of memory, the alert contains memory used
	Evaluations that hit output threshold can be shut down temporarily

* Sat Sep 29 2012 Lawrence R. Rogers <lrr@cert.org> 4.0.1-1
* Release 4.0.1-1
	Bug and compatability fixes.
	Additional debug statements.

* Tue Sep 28 2010 Lawrence R. Rogers <lrr@cert.org> 3.0.0-1
* Release 3.0.0-1
	Initial public release
